@@ -10,7 +10,7 @@ __all__ = 'encode',
 
 
 def encode(image_file, x_components, y_components):
-    image = Image.open(image_file)
+    image = Image.open(image_file).convert('RGB')
     red_band = image.getdata(band=0)
     green_band = image.getdata(band=1)
     blue_band = image.getdata(band=2)
